@@ -47,6 +47,7 @@
 #include <gdk/gdkdragsurface.h>
 #include <gdk/gdkdrawcontext.h>
 #include <gdk/gdkdrop.h>
+#include <gdk/gdkenums.h>
 #include <gdk/gdkenumtypes.h>
 #include <gdk/gdkevents.h>
 #include <gdk/gdkframeclock.h>
@@ -68,6 +69,7 @@
 #include <gdk/gdksnapshot.h>
 #include <gdk/gdksurface.h>
 #include <gdk/gdktexture.h>
+#include <gdk/gdktexturedownloader.h>
 #include <gdk/gdktoplevel.h>
 #include <gdk/gdktoplevellayout.h>
 #include <gdk/gdktoplevelsize.h>
@@ -75,8 +77,6 @@
 #include <gdk/gdkversionmacros.h>
 #include <gdk/gdkvulkancontext.h>
 
-#include <gdk/gdk-autocleanup.h>
-
 #undef __GDK_H_INSIDE__
 
 #endif /* __GDK_H__ */
