@@ -71,6 +71,9 @@ gboolean    gdk_display_supports_input_shapes (GdkDisplay    *display);
 GDK_AVAILABLE_IN_4_4
 gboolean    gdk_display_prepare_gl         (GdkDisplay  *self,
                                             GError     **error);
+GDK_AVAILABLE_IN_4_6
+GdkGLContext *gdk_display_create_gl_context(GdkDisplay  *self,
+                                            GError     **error);
 
 GDK_AVAILABLE_IN_ALL
 GdkDisplay *gdk_display_get_default (void);
@@ -80,10 +83,10 @@ GdkClipboard *          gdk_display_get_clipboard               (GdkDisplay
 GDK_AVAILABLE_IN_ALL
 GdkClipboard *          gdk_display_get_primary_clipboard       (GdkDisplay     *display);
 
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_4_10_FOR(gdk_toplevel_set_startup_id)
 void     gdk_display_notify_startup_complete   (GdkDisplay    *display,
                                                 const char    *startup_id);
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_4_10
 const char * gdk_display_get_startup_notification_id (GdkDisplay *display);
 
 GDK_AVAILABLE_IN_ALL
@@ -101,7 +104,7 @@ GDK_AVAILABLE_IN_ALL
 GdkMonitor * gdk_display_get_monitor_at_surface (GdkDisplay *display,
                                                 GdkSurface  *surface);
 
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_4_10
 void      gdk_display_put_event  (GdkDisplay     *display,
                                   GdkEvent       *event);
 
@@ -133,7 +136,7 @@ gboolean     gdk_display_get_setting (GdkDisplay *display,
                                       const char *name,
                                       GValue     *value);
 
-
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GdkDisplay, g_object_unref)
 
 G_END_DECLS
 
