@@ -36,7 +36,7 @@
  *
  * The minor version component of the library's version, e.g. "2" for "1.2.3".
  */
-#define GDK_MINOR_VERSION (8)
+#define GDK_MINOR_VERSION (10)
 
 /**
  * GDK_MICRO_VERSION:
@@ -118,6 +118,16 @@
  */
 #define GDK_VERSION_4_8        (G_ENCODE_VERSION (4, 8))
 
+/**
+ * GDK_VERSION_4_10:
+ *
+ * A macro that evaluates to the 4.10 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 4.10
+ */
+#define GDK_VERSION_4_10        (G_ENCODE_VERSION (4, 10))
+
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target, with a hard backstop to the
@@ -273,4 +283,18 @@
 # define GDK_DEPRECATED_IN_4_8_FOR(f)           _GDK_EXTERN
 #endif
 
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_4_10
+# define GDK_AVAILABLE_IN_4_10                  GDK_UNAVAILABLE(4, 10)
+#else
+# define GDK_AVAILABLE_IN_4_10                  _GDK_EXTERN
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_4_10
+# define GDK_DEPRECATED_IN_4_10                 GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_4_10_FOR(f)          GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_4_10                 _GDK_EXTERN
+# define GDK_DEPRECATED_IN_4_10_FOR(f)          _GDK_EXTERN
+#endif
+
 #endif  /* __GDK_VERSION_MACROS_H__ */
